==> flutter_flavorizr-1.0.11.tar.gz: lib/processors/android/google/firebase/android_firebase_processor.dart <==
/*
 * Copyright (c) 2021 MyLittleSuite
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

import 'package:flutter_flavorizr/processors/commons/copy_file_processor.dart';
import 'package:flutter_flavorizr/processors/commons/new_folder_processor.dart';
import 'package:flutter_flavorizr/processors/commons/queue_processor.dart';

class AndroidFirebaseProcessor extends QueueProcessor {
  AndroidFirebaseProcessor(
    String source,
    String destination,
    String flavorName,
  ) : super([
          NewFolderProcessor('$destination/$flavorName'),
          CopyFileProcessor(source, '$destination/$flavorName/google_services.json'),
        ]);

  @override
  String toString() => 'AndroidFirebaseProcessor';
}

==> flutter_flavorizr-2.0.0.tar.gz: lib/processors/android/google/firebase/android_firebase_processor.dart <==
/*
 * Copyright (c) 2021 MyLittleSuite
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

import 'package:flutter_flavorizr/parser/models/flavors/flavor.dart';
import 'package:flutter_flavorizr/processors/android/google/firebase/android_target_firebase_processor.dart';
import 'package:flutter_flavorizr/processors/commons/queue_processor.dart';

class AndroidFirebaseProcessor extends QueueProcessor {
  AndroidFirebaseProcessor({
    required String destination,
    required Map<String, Flavor> flavors,
  }) : super(
          flavors
              .map(
                (flavorName, flavor) => MapEntry(
                  flavorName,
                  AndroidTargetFirebaseProcessor(
                    flavor.android.firebase!.config,
                    destination,
                    flavorName,
                  ),
                ),
              )
              .values,
        );

  @override
  String toString() => 'AndroidFirebaseProcessor';
}
